@@ -104,6 +104,15 @@ class ClBuilderImageAction(Action):
          'method': 'Builder.remove_video_drivers(cl_builder_path)',
          'condition': lambda Get: Get('cl_builder_videodrv_set') == 'off'
          },
+        {'name': 'trim_reps',
+         'foreach': 'cl_builder_sync_rep',
+         'message': __("Cleaning the history of the {eachvar:capitalize} "
+                       "repository"),
+         'method': 'Builder.trimRepositories(eachvar)',
+         'condition': lambda Get: (
+             Get('cl_builder_sync_rep') and
+             Get('update.cl_update_onedepth_set') == 'on')
+         },
         {'name': 'creating_live_image',
          'group': __("Creating live image"),
          'tasks': [
