@@ -759,6 +759,11 @@ class VariableClBuilderImageFilename(Variable):
         if self.Get('cl_builder_id'):
             if not value:
                 raise VariableError(_("You must specify image filename"))
+            if not value.endswith(".iso"):
+                raise VariableError(_("You must specify image filename with "
+                                      "'iso' suffix"))
+            if path.isdir(value):
+                raise VariableError(_("The image shouldn't be a directory"))
             for line in process("/bin/losetup", "-j", value):
                 lodev, op, line = line.partition(":")
                 if lodev:
